Discover Packages
github.com/Ireoo/API-Core
libs
conf
package
Version:
v1.0.1
Opens a new window with list of versions in this module.
Published: Dec 10, 2019
License: Apache-2.0
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 2
Opens a new window with list of known importers.
Documentation
Documentation
¶
type Input struct {
Where bson .M `json:"where"`
Data bson .M `json:"data"`
Other struct {
Page int
Limit int
} `json:"other"`
Table string `json:"table"`
Mode string `json:"mode"`
Auth string `json:"auth"`
}
type MongoDB struct {
Host string `yaml:"Host"`
Auth string `yaml:"Auth"`
Username string `yaml:"Username"`
Password string `yaml:"Password"`
Timeout time .Duration `yaml:"Timeout"`
PoolLimit int `yaml:"PoolLimit"`
URI string `yaml:"URI"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.